; Dr. Wily's Commands

; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = QCF_ab
command = ~D, DF, F, a+b

[Command]
name = barrage
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = machassault
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = megabasket
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
name = callcaptains
command = ~40$B, F, a+b+c

;-| Special Motions |------------------------------------------------------
[Command]
name = QCF_a
command = ~D, DF, F, a

[Command]
name = QCF_b
command = ~D, DF, F, b

[Command]
name = QCF_c
command = ~D, DF, F, c

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCF_z
command = ~D, DF, F, z

[Command]
name = spindunka
command = ~F, D, DF, a

[Command]
name = spindunkb
command = ~F, D, DF, b

[Command]
name = spindunkc
command = ~F, D, DF, c

[Command]
name = shootx
command = ~F, DF, D, DB, B, x

[Command]
name = shooty
command = ~F, DF, D, DB, B, y

[Command]
name = shootz
command = ~F, DF, D, DB, B, z


[Command]
name = handmovedown
command = a+b+c

[Command]
name = handmoveup
command = x+y+z



;-------------Backwards------------

[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

;-Hold Direction----

[Command]
name = navy
command = ~40$B, F, x

[Command]
name = texas
command = ~40$B, F, y

[Command]
name = newyork
command = ~40$B, F, z

[Command]
name = florida
command = ~40$B, F, a

[Command]
name = lasvegas
command = ~40$B, F, b

[Command]
name = hawaii
command = ~40$B, F, c

;-Hold Button---------
[Command]
name = hold_a
command = /a
time = 1

[Command]
name = hold_b
command = /b
time = 1

[Command]
name = hold_c
command = /c
time = 1


;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = downfwd_a
command = /DF,a
time = 1

[Command]
name = downfwd_b
command = /DF,b
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

[Command]
name = thumbsup
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]



;==============SUPER ATTACKS===========
;---------------------------------------------------------------------------


;---------------------------------------------------------------------------
;Navy
[State -1]
type = ChangeState
value = 4001
trigger1 = command = navy
trigger1 = power >= 250
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = numhelper4100 < 1


;---------------------------------------------------------------------------
;Texas
[State -1]
type = ChangeState
value = 4002
trigger1 = command = texas
trigger1 = power >= 250
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = numhelper4200 < 1


;---------------------------------------------------------------------------
;New York
[State -1]
type = ChangeState
value = 4003
trigger1 = command = newyork
trigger1 = power >= 250
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = numhelper4300 < 1


;---------------------------------------------------------------------------
;Florida
[State -1]
type = ChangeState
value = 4004
trigger1 = command = florida
trigger1 = power >= 250
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = numhelper4400 < 1


;---------------------------------------------------------------------------
;Las Vegas
[State -1]
type = ChangeState
value = 4005
trigger1 = command = lasvegas
trigger1 = power >= 250
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = numhelper4500 < 1


;---------------------------------------------------------------------------
;Hawaii
[State -1]
type = ChangeState
value = 4006
trigger1 = command = hawaii
trigger1 = power >= 250
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = numhelper4600 < 1

;==========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1]
type = ChangeState
value = 195
trigger1 = command = thumbsup
trigger1 = command != holddown
trigger1 = statetype = S
trigger1 = stateno != 195
trigger1 = ctrl = 1


;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Air_Throw1
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = fwd_ab
trigger2 = command = back_ab
;---------------------------
;Air_Throw1 (second set of commands)
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b


;===========================================================================
;---------------------------------------------------------------------------

;---------------------------
;Hands In
[State -1]
type = ChangeState
value = 193
triggerall = stateno = 0
trigger1 = numhelper1000 = 0
trigger1 = numhelper2000 = 0


;---------------------------
;Disable Blocking
[State -2]
type = Assertspecial
flag = nostandguard
flag2 = nocrouchguard
flag3 = noairguard
trigger1 = time > 0
trigger2 = command = holdback







